package Acme::MetaSyntactic::barbarella;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::barbarella - Characters from the movie.

=head1 DESCRIPTION

According to L<http://www.hollywoodcomics.com/forestbbd.html>, 
Jean-Claude Forest created the character of Barbarella for I<V-Magazine>
in 1962. Barbarella was an immediate runaway bestseller and was soon
translated in a dozen countries. Not long after, it was adapted into
a major motion picture, starring Jane Fonda, for which Forest acted as
design consultant.

This theme lists the main characters from the 1968 movie, I<Barbarella>,
starring Jane Fonda.

The list is taken from L<http://www.imdb.com/title/tt0062711/fullcredits>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-01-16

Introduced in Acme-MetaSyntactic version 0.57.

=item *

2005-10-26

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>,

=cut

__DATA__
# names
Barbarella Pygar The_Great_Tyrant Durand_Durand Professor_Ping
President_of_Earth Captain_Moon Captain_Sun Stomoxys Glossina
Dildano Mark_Hand
